# PeerReviewV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV20**](CreatedDateV20.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV20**](LastModifiedDateV20.md) |  | [optional] 
**source** | [**SourceV20**](SourceV20.md) |  | [optional] 
**reviewer_role** | **str** |  | [optional] 
**review_identifiers** | [**ExternalIDsV20**](ExternalIDsV20.md) |  | [optional] 
**review_url** | [**UrlV20**](UrlV20.md) |  | [optional] 
**review_type** | **str** |  | [optional] 
**review_completion_date** | [**FuzzyDateV20**](FuzzyDateV20.md) |  | [optional] 
**review_group_id** | **str** |  | 
**subject_external_identifier** | [**ExternalIDV20**](ExternalIDV20.md) |  | [optional] 
**subject_container_name** | [**TitleV20**](TitleV20.md) |  | [optional] 
**subject_type** | **str** |  | [optional] 
**subject_name** | [**WorkTitleV20**](WorkTitleV20.md) |  | [optional] 
**subject_url** | [**UrlV20**](UrlV20.md) |  | [optional] 
**convening_organization** | [**OrganizationV20**](OrganizationV20.md) |  | 
**visibility** | **str** |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

